@@ -1075,6 +1075,47 @@ MISSPELLED_WORD = _("Misspelled word: %s")
 # containing the misspelled word in the document. This is known as the context.
 MISSPELLED_WORD_CONTEXT = _("Context is %s")
 
+# Translators: Orca has a number of commands that override the default
+# behavior within an application. For instance, on a web page, "h" moves
+# you to the next heading. What should happen when you press an "h" in
+# an entry on a web page depends: If you want to resume reading content,
+# "h" should move to the next heading; if you want to enter text, "h"
+# should not not move you to the next heading. Similarly, if you are
+# at the bottom of an entry and press Down arrow, should you leave the
+# entry? Again, it depends on if you want to resume reading content or
+# if you are editing the text in the entry. Because Orca doesn't know
+# what you want to do, it has two modes: In browse mode, Orca treats
+# key presses as commands to read the content; in focus mode, Orca treats
+# key presses as something that should be handled by the focused widget.
+# This string is the message presented when Orca switches to browse mode.
+MODE_BROWSE = _("Browse mode")
+
+# Translators: Orca has a number of commands that override the default
+# behavior within an application. For instance, on a web page, "h" moves
+# you to the next heading. What should happen when you press an "h" in
+# an entry on a web page depends: If you want to resume reading content,
+# "h" should move to the next heading; if you want to enter text, "h"
+# should not not move you to the next heading. Similarly, if you are
+# at the bottom of an entry and press Down arrow, should you leave the
+# entry? Again, it depends on if you want to resume reading content or
+# if you are editing the text in the entry. Because Orca doesn't know
+# what you want to do, it has two modes: In browse mode, Orca treats
+# key presses as commands to read the content; in focus mode, Orca treats
+# key presses as something that should be handled by the focused widget.
+# This string is the message presented when Orca switches to focus mode.
+MODE_FOCUS = _("Focus mode")
+
+# Translators: (Please see the previous, detailed translator notes about
+# Focus mode and Browse mode.) In order to minimize the amount of work Orca
+# users need to do to switch between focus mode and browse mode, Orca attempts
+# to automatically switch to the mode which is appropriate to the current
+# web element. Sometimes, however, this automatic mode switching is not what
+# the user wants. A good example being web apps which have their own keyboard
+# navigation and use interaction model. As a result, Orca has a command which
+# enables setting a "sticky" focus mode which disables all automatic toggling.
+# This string is the message presented when Orca switches to sticky focus mode.
+MODE_FOCUS_IS_STICKY = _("Focus mode is sticky.")
+
 # Translators: Hovering the mouse over certain objects on a web page causes a 
 # new object to appear such as a pop-up menu. Orca has a command will move the
 # user to the object which just appeared as a result of the user hovering the
@@ -1106,11 +1147,6 @@ NO_FOCUS =  _("No focus")
 # has keyboard focus.
 NO_FOCUSED_APPLICATION =  _("No application has focus.")
 
-# Translators: This is for navigating document content by moving from anchor to
-# anchor. (An anchor is a named spot that one can jump to.) This is a detailed
-# message which will be presented to the user if no more anchors can be found.
-NO_MORE_ANCHORS = _("No more anchors.")
-
 # Translators: This is for navigating document content by moving from blockquote
 # to blockquote. This is a detailed message which will be presented to the user
 # if no more blockquotes can be found.
@@ -1132,6 +1168,11 @@ NO_MORE_CHECK_BOXES = _("No more check boxes.")
 # will be presented to the user if no more check boxes can be found.
 NO_MORE_CHUNKS = _("No more large objects.")
 
+# Translators: This is for navigating document content by moving amongst web
+# elements which have an "onClick" action. This is a detailed message which
+# will be presented to the user if no more clickable elements can be found.
+NO_MORE_CLICKABLES = _("No more clickables.")
+
 # Translators: This is for navigating document content by moving from combo
 # box to combo box. This is a detailed message which will be presented to the
 # user if no more combo boxes can be found.
@@ -1158,6 +1199,11 @@ NO_MORE_HEADINGS = _("No more headings.")
 # at the desired level can be found.
 NO_MORE_HEADINGS_AT_LEVEL = _("No more headings at level %d.")
 
+# Translators: This is for navigating document content by moving from image
+# to image. This is a detailed message which will be presented to the user
+# if no more images can be found.
+NO_MORE_IMAGES = _("No more images.")
+
 # Translators: this is for navigating to the previous ARIA role landmark.
 # ARIA role landmarks are the W3C defined HTML tag attribute 'role' used to
 # identify important part of webpage like banners, main context, search etc.
