@@ -560,7 +560,6 @@ class Utilities:
         except (LookupError, RuntimeError):
             role = None
 
-        role = obj.getRole()
         if role == pyatspi.ROLE_PUSH_BUTTON and obj.name:
             return obj.name
 
@@ -2720,3 +2719,9 @@ class Utilities:
         red, green, blue = string.split(",")
 
         return int(red), int(green), int(blue)
+
+    def isClickableElement(self, obj):
+        return False
+
+    def hasLongDesc(self, obj):
+        return False
