@@ -136,6 +136,7 @@ class Utilities(script_utilities.Utilities):
             bogus = False
             if self._script.inDocumentContent() \
                and obj.getRole() in [pyatspi.ROLE_COMBO_BOX,
+                                     pyatspi.ROLE_LIST_BOX,
                                      pyatspi.ROLE_LIST]:
                 # Bogus case #1:
                 # <label></label> surrounding the entire combo box/list which
@@ -258,17 +259,6 @@ class Utilities(script_utilities.Utilities):
 
         return False
 
-    def isLayoutOnly(self, obj):
-        """Returns True if the given object is for layout purposes only."""
-
-        if self._script.isUselessObject(obj):
-            debug.println(debug.LEVEL_FINEST,
-                          "Object deemed to be useless: %s" % obj)
-            return True
-
-        else:
-            return script_utilities.Utilities.isLayoutOnly(self, obj)
-
     def isPasswordText(self, obj):
         """Returns True if we should treat this object as password text."""
 
@@ -609,3 +599,41 @@ class Utilities(script_utilities.Utilities):
                 objects.extend(toAdd)
 
         return objects
+
+    def isClickableElement(self, obj):
+        if not self._script.inDocumentContent(obj):
+            return False
+
+        # For Gecko, we want to identify things which are ONLY clickable.
+        # Things which are focusable, while technically "clickable", are
+        # easily discoverable (e.g. via role) and activatable (e.g. via
+        # pressing Space or Enter.
+        state = obj.getState()
+        if state.contains(pyatspi.STATE_FOCUSABLE):
+            return False
+
+        try:
+            action = obj.queryAction()
+        except NotImplementedError:
+            return False
+
+        for i in range(action.nActions):
+            if action.getName(i) in ["click"]:
+                return True
+
+        return False
+
+    def hasLongDesc(self, obj):
+        if not self._script.inDocumentContent(obj):
+            return False
+
+        try:
+            action = obj.queryAction()
+        except NotImplementedError:
+            return False
+
+        for i in range(action.nActions):
+            if action.getName(i) in ["showlongdesc"]:
+                return True
+
+        return False
