@@ -111,6 +111,8 @@ userCustomizableSettings = [
     "useColorNames",
     "findResultsVerbosity",
     "findResultsMinimumLength",
+    "structNavTriggersFocusMode",
+    "caretNavTriggersFocusMode",
 ]
 
 GENERAL_KEYBOARD_LAYOUT_DESKTOP = 1
@@ -356,3 +358,6 @@ sounds = {}
 # TODO - JD: Is this still needed now that AT-SPI has its own timeout?
 timeoutTime             = 10   # a value of 0 means don't do hang checking
 timeoutCallback         = None # Set by orca.py:init to orca.timeout
+
+structNavTriggersFocusMode = False
+caretNavTriggersFocusMode = False
