@@ -222,6 +222,26 @@ class SpeechGenerator(generator.Generator):
             result.extend(acss)
         return result
 
+    def _generateClickable(self, obj, **args):
+        if _settingsManager.getSetting('onlySpeakDisplayedText'):
+            return []
+
+        acss = self.voice(SYSTEM)
+        result = generator.Generator._generateClickable(self, obj, **args)
+        if result:
+            result.extend(acss)
+        return result
+
+    def _generateHasLongDesc(self, obj, **args):
+        if _settingsManager.getSetting('onlySpeakDisplayedText'):
+            return []
+
+        acss = self.voice(SYSTEM)
+        result = generator.Generator._generateHasLongDesc(self, obj, **args)
+        if result:
+            result.extend(acss)
+        return result
+
     def _generateTextRole(self, obj, **args):
         """A convenience method to prevent the pyatspi.ROLE_PARAGRAPH role
         from being spoken. In the case of a pyatspi.ROLE_PARAGRAPH
@@ -1372,7 +1392,7 @@ class SpeechGenerator(generator.Generator):
     def _generateFocusedItem(self, obj, **args):
         result = []
         role = args.get('role', obj.getRole())
-        if role != pyatspi.ROLE_LIST:
+        if role not in [pyatspi.ROLE_LIST, pyatspi.ROLE_LIST_BOX]:
             return result
 
         try:
